@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>                      */
+/* Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>                      */
 
 // Local Includes
 #include "filters.h"
@@ -147,7 +147,7 @@ void Filter::setInfo(const QString &_info)
     d->info = _info;
 }
 
-bool Filter::importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, MailImporter::MessageStatus status)
+bool Filter::importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, const MailImporter::MessageStatus &status)
 {
     return filterImporter()->importMessage(folderName, msgPath, duplicateCheck, status);
 }
