@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -185,7 +185,11 @@ void FilterBalsa::importFiles(const QString &dirName)
                 _path = i18nc("define folder name where we import evolution mails", "Evolution-Import");
                 QString _tmp = dir.filePath(*mailFile);
                 _tmp.remove(mailDir(), Qt::CaseSensitive);
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
                 QStringList subFList = _tmp.split(QLatin1Char('/'), QString::SkipEmptyParts);
+#else
+                QStringList subFList = _tmp.split(QLatin1Char('/'), Qt::SkipEmptyParts);
+#endif
                 QStringList::ConstIterator end(subFList.end());
                 for (QStringList::ConstIterator it = subFList.constBegin(); it != end; ++it) {
                     QString _cat = *it;
