@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-/* Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>                      */
+/* Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>                      */
 
 #include "filterthebat.h"
 
@@ -241,7 +241,9 @@ void FilterTheBat::importFiles(const QString &FileName)
                 tmp.write(input.constData(), endPos - lastPos);
                 tmp.flush();
 
-                importMessage(_path, tmp.fileName(), filterInfo()->removeDupMessage());
+                if (!importMessage(_path, tmp.fileName(), filterInfo()->removeDupMessage())) {
+                    filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+                }
 
                 lastPos = endPos + 48;
                 tbb.seek(lastPos);
