@@ -350,8 +350,9 @@ void FilterThunderbird::importMBox(const QString &mboxName, const QString &rootD
                     destFolder.remove(QStringLiteral(".sbd"));
                 }
             }
-
-            importMessage(destFolder, tmp.fileName(), filterInfo()->removeDupMessage());
+            if (!importMessage(destFolder, tmp.fileName(), filterInfo()->removeDupMessage())) {
+                filterInfo()->addErrorLogEntry(i18n("Could not import %1", tmp.fileName()));
+            }
 
             int currentPercentage = (int)(((float)mbox.pos() / filenameInfo.size()) * 100);
             filterInfo()->setCurrent(currentPercentage);
