@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ using namespace MailImporter;
 SelectThunderbirdProfileDialog::SelectThunderbirdProfileDialog(QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle(i18n("Select thunderbird profile"));
+    setWindowTitle(i18nc("@title:window", "Select thunderbird profile"));
     setModal(true);
     QVBoxLayout *topLayout = new QVBoxLayout(this);
 
